====================
Source documentation
====================

mrcfile -- Main package
-----------------------

.. automodule:: mrcfile
    :members: new, open, read, write, open_async, mmap, new_mmap, validate
    :undoc-members:
    :show-inheritance:
    
    Members
    -------

Submodules
----------

mrcfile.bzip2mrcfile module
---------------------------

.. automodule:: mrcfile.bzip2mrcfile
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.command_line module
---------------------------

.. automodule:: mrcfile.command_line
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.constants module
------------------------

.. automodule:: mrcfile.constants
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.dtypes module
---------------------

.. automodule:: mrcfile.dtypes
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.future_mrcfile module
-----------------------------

.. automodule:: mrcfile.future_mrcfile
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.gzipmrcfile module
--------------------------

.. automodule:: mrcfile.gzipmrcfile
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.load_functions module
-----------------------------

.. automodule:: mrcfile.load_functions
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.mrcfile module
----------------------

.. automodule:: mrcfile.mrcfile
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.mrcinterpreter module
-----------------------------

.. automodule:: mrcfile.mrcinterpreter
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.mrcmemmap module
------------------------

.. automodule:: mrcfile.mrcmemmap
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.mrcobject module
------------------------

.. automodule:: mrcfile.mrcobject
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.utils module
--------------------

.. automodule:: mrcfile.utils
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:

mrcfile.validator module
------------------------

.. automodule:: mrcfile.validator
    :special-members: __init__
    :members:
    :undoc-members:
    :private-members:
    :show-inheritance:


